# IMRT-QA-Data-Miner
Scans a directory for SNC Patient IMRT QA results.


### Install
~~~~
$ pip install imrt-qa-data-miner
~~~~


### How to run
~~~~
$ imrt-qa-data-miner <abs-directory-to-start-scan> <optional-output-filename>
~~~~
